==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaPokoj.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DpsJednostkaPokoj extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_POKOJ.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_POKOJ.BUDYNEK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String budynek;

    /**
     * DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer liczbaMiejsc;

    /**
     * DPS_JEDNOSTKA_POKOJ.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DPS_JEDNOSTKA_POKOJ.PIETRO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer pietro;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_POKOJ.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.BUDYNEK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getBudynek() {
        return budynek;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.BUDYNEK
     *
     * @param budynek
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setBudynek(String budynek) {
        this.budynek = budynek == null ? null : budynek.trim();
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLiczbaMiejsc() {
        return liczbaMiejsc;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     *
     * @param liczbaMiejsc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiczbaMiejsc(Integer liczbaMiejsc) {
        this.liczbaMiejsc = liczbaMiejsc;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.PIETRO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getPietro() {
        return pietro;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.PIETRO
     *
     * @param pietro
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPietro(Integer pietro) {
        this.pietro = pietro;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaPokoj other = (DpsJednostkaPokoj) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getBudynek() == null ? other.getBudynek() == null : this.getBudynek().equals(other.getBudynek()))
            && (this.getLiczbaMiejsc() == null ? other.getLiczbaMiejsc() == null : this.getLiczbaMiejsc().equals(other.getLiczbaMiejsc()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getPietro() == null ? other.getPietro() == null : this.getPietro().equals(other.getPietro()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getBudynek() == null) ? 0 : getBudynek().hashCode());
        result = prime * result + ((getLiczbaMiejsc() == null) ? 0 : getLiczbaMiejsc().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getPietro() == null) ? 0 : getPietro().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", budynek=").append(budynek);
        sb.append(", liczbaMiejsc=").append(liczbaMiejsc);
        sb.append(", nr=").append(nr);
        sb.append(", pietro=").append(pietro);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaPokoj.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DpsJednostkaPokoj extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_POKOJ.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_POKOJ.BUDYNEK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String budynek;

    /**
     * DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer liczbaMiejsc;

    /**
     * DPS_JEDNOSTKA_POKOJ.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DPS_JEDNOSTKA_POKOJ.PIETRO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer pietro;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_POKOJ.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.BUDYNEK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getBudynek() {
        return budynek;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.BUDYNEK
     *
     * @param budynek
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setBudynek(String budynek) {
        this.budynek = budynek == null ? null : budynek.trim();
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLiczbaMiejsc() {
        return liczbaMiejsc;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.LICZBA_MIEJSC
     *
     * @param liczbaMiejsc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiczbaMiejsc(Integer liczbaMiejsc) {
        this.liczbaMiejsc = liczbaMiejsc;
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DPS_JEDNOSTKA_POKOJ.PIETRO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getPietro() {
        return pietro;
    }

    /**
     * DPS_JEDNOSTKA_POKOJ.PIETRO
     *
     * @param pietro
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPietro(Integer pietro) {
        this.pietro = pietro;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaPokoj other = (DpsJednostkaPokoj) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getBudynek() == null ? other.getBudynek() == null : this.getBudynek().equals(other.getBudynek()))
            && (this.getLiczbaMiejsc() == null ? other.getLiczbaMiejsc() == null : this.getLiczbaMiejsc().equals(other.getLiczbaMiejsc()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getPietro() == null ? other.getPietro() == null : this.getPietro().equals(other.getPietro()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getBudynek() == null) ? 0 : getBudynek().hashCode());
        result = prime * result + ((getLiczbaMiejsc() == null) ? 0 : getLiczbaMiejsc().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getPietro() == null) ? 0 : getPietro().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", budynek=").append(budynek);
        sb.append(", liczbaMiejsc=").append(liczbaMiejsc);
        sb.append(", nr=").append(nr);
        sb.append(", pietro=").append(pietro);
        sb.append("]");
        return sb.toString();
    }
}
